@@ -9,6 +9,8 @@ import time
 import re
 import json
 import md5
+import datetime
+from dateutil.relativedelta import relativedelta
 from unicodedata import normalize
 from functools import wraps
 
@@ -69,7 +71,7 @@ def pegar_versao_git():
     import subprocess
 
     version = None
-    
+
     # 1. Tenta buscar a versao do GIT
     try:
         version = subprocess.check_output(['git', 'rev-parse', '--short', 'HEAD'])
@@ -80,20 +82,23 @@ def pegar_versao_git():
                 version = f.read()
             version = version.replace("\n","")
 
-    # 2. Busca o nome da Aplicacao no Beanstalk
+    # 2. Busca o nome da Aplicacao ou o Deploy ID no Beanstalk
     if not version:
         try:
             file = open('/opt/elasticbeanstalk/deploy/manifest','r')
             json_dict = json.loads(file)
-            version = json_dict.get('VersionLabel')
+            version = json_dict.get('VersionLabel', None)
+
+            if not version:
+                version = json_dict.get('DeploymentId')
         except:
             pass
 
     # 3. Usa a variável de ambiente
     if not version:
-        version = os.environ.get('VERSION')
+        version = os.environ.get('HOSTNAME')
 
-    # Retorna o hash 
+    # Retorna o hash
     if version:
         try:
             version = md5.new(str(version)).hexdigest()[:7]
@@ -193,4 +198,46 @@ def to_camel_case(snake_str):
 
 def to_underscore_case(name):
     s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
-    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()
\ No newline at end of file
+    return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()
+
+
+def get_current_month_cycle(initial_date, final_date):
+    """
+    Descobre e retorna o ciclo mensal atual para assinaturas com período maior que 1 mes
+    :param initial_date: date
+    :param final_date: date
+    :return: dict
+    """
+    today = datetime.date.today()
+    total_months = (final_date.year - initial_date.year) * 12 + (final_date.month - initial_date.month)
+    # Se o ciclo tiver apenas 1 mes nao precisa calcular nada
+    if total_months in {0,1}:
+        return { "initial": initial_date, "final": final_date }
+
+    cycle = { "initial": None, "final": None }
+    for month in range(total_months):
+        cycle['initial'] = cycle['final'] + relativedelta(days=1) if cycle['initial'] is not None else initial_date
+        # Ultimo mes deve acabar no final do ciclo assinado
+        if month < 11:
+            cycle['final'] = cycle['initial'] + relativedelta(months=1)
+            if cycle['initial'].day == cycle['final'].day:
+                cycle['final'] = cycle['final'] - relativedelta(days=1)
+        else:
+            cycle['final'] = final_date
+        # Chegamos ao ciclo que corresponde ao atual
+        if today >= cycle['initial'] and today <= cycle['final']:
+            break
+
+    return cycle
+
+
+def get_months_between(final_date, initial_date):
+    """
+    Retorna a quantidade de meses entre duas datas
+    :param initial_date: date
+    :param final_date: date
+    :return: int
+    """
+    diff = relativedelta(final_date, initial_date)
+    months = abs(diff.months + diff.years * 12)
+    return months if diff.days <= 1 else months + 1
